@@ -3,7 +3,7 @@ use warnings;
 use v5.8.0;
 
 package Dist::Zilla::Plugin::NexusRelease;
-$Dist::Zilla::Plugin::NexusRelease::VERSION = '0.0.2';
+$Dist::Zilla::Plugin::NexusRelease::VERSION = '0.0.3';
 
 # ABSTRACT: Release a Dist::Zilla build to a Sonatype Nexus instance.
 
@@ -20,7 +20,7 @@ use namespace::autoclean;
 {
 
     package Dist::Zilla::Plugin::NexusRelease::_Uploader;
-$Dist::Zilla::Plugin::NexusRelease::_Uploader::VERSION = '0.0.2';
+$Dist::Zilla::Plugin::NexusRelease::_Uploader::VERSION = '0.0.3';
     # Nexus::Uploader will be loaded later if used
     our @ISA = 'Nexus::Uploader';
 
@@ -133,7 +133,7 @@ sub release {
     }
 
     $log->info('Releasing to Sonatype Nexus');
-    $self->uploader->upload_file($archive);
+    $self->uploader->upload_file("$archive");
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -152,7 +152,7 @@ Dist::Zilla::Plugin::NexusRelease - Release a Dist::Zilla build to a Sonatype Ne
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
@@ -217,7 +217,6 @@ The version of the distribution - defaults to the $VERSION set in the distributi
 
 The C<release> method required by L<Dist::Zilla::Role::Releaser>.
 
-
 =head1 SEE ALSO
 
 - L<Nexus::Uploader>
@@ -229,7 +228,7 @@ Brad Macpherson <brad@teched-creations.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Brad Macpherson.
+This software is copyright (c) 2016 by Brad Macpherson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
